mm-commits.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
* [merged] coda-fix-reference-counting-in-coda_file_mmap-error-path.patch removed from -mm tree
@ 2021-05-08 22:38 akpm
  0 siblings, 0 replies; only message in thread
From: akpm @ 2021-05-08 22:38 UTC (permalink / raw)
  To: christian.koenig, daniel.vetter, jaharkes, jgg, miklos,
	mm-commits, stable


The patch titled
     Subject: coda: fix reference counting in coda_file_mmap error path
has been removed from the -mm tree.  Its filename was
     coda-fix-reference-counting-in-coda_file_mmap-error-path.patch

This patch was dropped because it was merged into mainline or a subsystem tree

------------------------------------------------------
From: Christian König <christian.koenig@amd.com>
Subject: coda: fix reference counting in coda_file_mmap error path

mmap_region() now calls fput() on the vma->vm_file.

So we need to drop the extra reference on the coda file instead of the
host file.

Link: https://lkml.kernel.org/r/20210421132012.82354-1-christian.koenig@amd.com
Fixes: 1527f926fd04 ("mm: mmap: fix fput in error path v2")
Signed-off-by: Christian König <christian.koenig@amd.com>
Reviewed-by: Daniel Vetter <daniel.vetter@ffwll.ch>
Acked-by: Jan Harkes <jaharkes@cs.cmu.edu>
Cc: Miklos Szeredi <miklos@szeredi.hu>
Cc: Jason Gunthorpe <jgg@ziepe.ca>
Cc: <stable@vger.kernel.org>	[5.11+]
Signed-off-by: Andrew Morton <akpm@linux-foundation.org>
---

 fs/coda/file.c |    6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

--- a/fs/coda/file.c~coda-fix-reference-counting-in-coda_file_mmap-error-path
+++ a/fs/coda/file.c
@@ -175,10 +175,10 @@ coda_file_mmap(struct file *coda_file, s
 	ret = call_mmap(vma->vm_file, vma);
 
 	if (ret) {
 		/* if call_mmap fails, our caller will put coda_file so we
 		 * should drop the reference to the host_file that we got.
 		 */
-		fput(host_file);
+		fput(coda_file);
 		kfree(cvm_ops);
 	} else {
 		/* here we add redirects for the open/close vm_operations */
_

Patches currently in -mm which might be from christian.koenig@amd.com are



^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2021-05-08 22:38 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -175,10 +175,10 @@ coda_file_mmap(struct file *coda_file, s
 
 	if (ret) {
-		/* if call_mmap fails, our caller will put coda_file so we
-		 * should drop the reference to the host_file that we got.
+		/* if call_mmap fails, our caller will put host_file so we
+		 * should drop the reference to the coda_file that we got.
 		 */
2021-05-08 22:38 [merged] coda-fix-reference-counting-in-coda_file_mmap-error-path.patch removed from -mm tree akpm

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).